<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class File extends Model
{

    /**
     * Use unix timestamps.
     * @var type
     */
    protected $dateFormat = 'U';

    public function directory() {
        return $this->belongsTo("\App\Directory");
    }

    /**
     * Get the human readable file size.
     * @return string
     */
    public function sizeHuman() : string {
        return self::humanFilesize($this->size, 1);
    }

    public function ageHuman() : string {
        return $this->created_at->diffForHumans();
    }

    public function downloadUrl() : string {
        return url($this->directory->path() . "/" . $this->name);
    }

    public static function findByPath(string $path) : ?File {
        $dir_path = trim(dirname($path), '.');
        $file_name = basename($path);

        $directory = Directory::findByPath($dir_path);
        if ($directory == null) {
            return null;
        }

        return $directory->findFileByName($file_name, false);
    }

    public static function humanFilesize($bytes, $decimals = 2) {
        $size = array('B', 'kB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB');
        $factor = floor((strlen($bytes) - 1) / 3);
        return sprintf("%.{$decimals}f", $bytes / pow(1024, $factor)) . @$size[$factor];
    }
}
